@@ -14,9 +14,8 @@
 #' data(dolph.msats)
 #' is.gtypes(dolph.msats) # FALSE
 #' 
-#' @importFrom methods is
 #' @export
 #' 
 is.gtypes <- function(x) {
-  if(is(x, "gtypes")) validObject(x) else FALSE
+  if(methods::is(x, "gtypes")) methods::validObject(x) else FALSE
 }
\ No newline at end of file
