@@ -20,21 +20,21 @@
 #' @export
 #' 
 neiDa <- function(g) {
-  if(ploidy(g) == 1 & !is.null(sequences(g))) g <- labelHaplotypes(g)$gtypes
-  st.pairs <- as.matrix(.strataPairs(g))
-  st <- g@data$strata
+  if(getNumStrata(g) < 2) stop("cannot compute Nei's Da with < 2 strata")
+  g <- .checkHapsLabelled(g)
   
-  .DaFunc <- function(locus, st, sp) {
-    to.use <- st %in% sp & !is.na(st) & !is.na(locus)
-    freqs <- prop.table(table(locus[to.use], st[to.use]))
-    sum(apply(freqs, 1, function(f) {
-      if(all(f == 0)) NA else sqrt(prod(f))
-    }), na.rm = TRUE)
-  }
-
-  Da <- apply(st.pairs, 1, function(sp) {
-    loc.sum <- g@data[, sapply(.SD, .DaFunc, st = st, sp = sp), .SDcols = !c("ids", "strata")]
+  freqs <- alleleFreqs(g, by.strata = TRUE)
+  .DaFunc <- function(st1, st2, freqs) {    
+    loc.sum <- purrr::map_dbl(freqs, function(loc.freqs) {
+      freqs.st <- prop.table(loc.freqs[, c(st1, st2), drop = FALSE])
+      apply(freqs.st, 1, function(f) if(all(f == 0)) NA else sqrt(prod(f))) %>% 
+        sum(na.rm = TRUE)
+    }) 
     1 - sum(loc.sum, na.rm = TRUE) / sum(!is.na(loc.sum))
-  })
-  cbind(data.frame(st.pairs), Da = Da)
+  }
+  
+  .strataPairs(g) %>% 
+    dplyr::rowwise() %>% 
+    dplyr::mutate(Da = .DaFunc(.data$strata.1, .data$strata.2, freqs)) %>% 
+    as.data.frame()
 }
\ No newline at end of file
