@@ -18,10 +18,10 @@
 #' @export
 #' 
 permuteStrata <- function(g) {
-  st <- strata(g)
+  st <- getStrata(g)
   no.nas <- st[!is.na(st)]
-  no.na.sample <- sample(as.character(no.nas))
-  names(no.na.sample) <- names(no.nas)
-  strata(g) <- factor(no.na.sample[names(st)])
+  no.na.perm <- sample(no.nas)
+  names(no.na.perm) <- names(no.nas)
+  setStrata(g) <- stats::setNames(no.na.perm[names(st)], names(st))
   g
 }
\ No newline at end of file
