@@ -16,8 +16,6 @@
 #' haps <- simGammaHaps(1000, 15, 1, 2.5)
 #' print(haps)
 #'
-#' @importFrom graphics layout par curve hist box
-#' @importFrom stats dgamma
 #' @export
 #' 
 simGammaHaps <- function(pop.size, num.haps, shape, scale,
@@ -25,7 +23,7 @@ simGammaHaps <- function(pop.size, num.haps, shape, scale,
   if(num.haps > pop.size) stop("'num.haps' must be smaller than 'pop.size'.")
 
   # get frequency of each haplotype from gamma
-  hap.freq <- dgamma(1:num.haps, shape = shape, scale = scale)
+  hap.freq <- stats::dgamma(1:num.haps, shape = shape, scale = scale)
   hap.freq <- ceiling(hap.freq * pop.size / sum(hap.freq))
   
   # create "individuals"
@@ -33,18 +31,11 @@ simGammaHaps <- function(pop.size, num.haps, shape, scale,
   haplotypes <- sample(haplotypes, pop.size)
 
   if(plot) {
-    gamma.func <- function(x) dgamma(x, shape = shape, scale = scale)
-    layout(matrix(c(1, 2), nrow = 2))
-    op <- par(mar = c(4, 4, 3, 1) + 0.1)
-    curve(gamma.func, 0, num.haps,
-          xlab = "Haplotype", ylab = "Density",
-          main = paste("Gamma(", shape, ", ", scale, ")", sep = "")
-    )
-    par(mar = c(5, 4, 1, 1) + 0.1)
-    hist(haplotypes, xlab = "Haplotype", ylab = "Density", main = "")
-    box()
-    layout(matrix(1, 1))
-    par(op)
+    p <- tibble::tibble(Haplotypes = haplotypes) %>% 
+      ggplot2::ggplot(ggplot2::aes_string("Haplotypes")) +
+      ggplot2::geom_histogram(binwidth = 1) +
+      ggplot2::ylab("Count")
+    print(p)
   }
 
   if(return.freq) table(haplotypes) else haplotypes
