@@ -6,6 +6,9 @@
 #' @title Summaries and population structure analyses of DNA sequence genotypic 
 #'   data
 #' @keywords package
+#' @importFrom rlang .data
+#' @importFrom magrittr %>%
+#' 
 NULL
 
 #' @docType data
@@ -115,4 +118,6 @@ NULL
 #'   demographic analyses of bowhead whales. 
 #'   Endangered Species Research 19, 129-147.
 #' @keywords datasets
-NULL
\ No newline at end of file
+NULL
+
+globalVariables(c("id", "locus", "stratum", "allele"))
\ No newline at end of file
