@@ -2,10 +2,11 @@
 #' @description Calculate theta from heterozygosity of each locus.
 #' 
 #' @param g a \linkS4class{gtypes} object.
+#' @param by.strata logical - return results grouped by strata?
 #' 
 #' @return vector of theta values for each locus.
 #' 
-#' @details Calculates theta for each locus using the 
+#' @details Calculates theta for each locus using the
 #'   \code{\link[pegas]{theta.h}} function.
 #' 
 #' @author Eric Archer \email{eric.archer@@noaa.gov}
@@ -15,11 +16,11 @@
 #' 
 #' theta(msats.g)
 #' 
-#' @importFrom pegas theta.h
-#' @importFrom stats na.omit
 #' @export
 #' 
-theta <- function(g) {
-  .thetaFunc <- function(x) theta.h(na.omit(x))
-  g@data[, sapply(.SD, .thetaFunc), .SDcols = !c("ids", "strata")]
+theta <- function(g, by.strata = FALSE) {
+  .thetaFunc <- function(x) pegas::theta.h(stats::na.omit(x))
+  .applyPerLocus(.thetaFunc, g, by.strata = by.strata) %>%
+    dplyr::rename(theta = .data$value) %>% 
+    as.data.frame()
 }
\ No newline at end of file
