@@ -9,15 +9,15 @@
 #' @export
 #' 
 write.nexus.snapp <- function(g, file = "snapp.data.nex") {
-  result <- numericSNPmat(g)
+  result <- as.data.frame(g, coded.snps = TRUE)
+  strata <- gsub("[ _]", ".", result$stratum)
+  id <- gsub("[ _]", ".", result$id)
+  result$id <- result$stratum <- NULL
   
-  result[is.na(result)] <- "?"
-  result <- lapply(1:nrow(result), function(i) result[i, ])
-  strata <- gsub("[ _]", ".", strata(g))
-  id <- gsub("[ _]", ".", indNames(g))
+  result <- lapply(1:nrow(result), function(i) result[i, -(1:2)])
   names(result) <- paste(strata, id, sep = "_")
   
-  write.nexus.data(result, file = file)
+  ape::write.nexus.data(result, file = file)
   
   snapp.file <- scan(file, what = "character", sep = "\n", quiet = TRUE)
   bgn <- grep("BEGIN", snapp.file)
